@@ -1,9 +1,9 @@
-__version__         = '0.2.2'
-__author__          = "Dave Martorana (http://davemartorana.com) & Richard Cooper (http://frozenskys.com)"
+__version__         = '0.3.1'
+__author__          = "Dave Martorana (http://davemartorana.com), Richard Cooper (http://frozenskys.com), Bill Jones (oraclebill), Dmitry Golomidov (deeGraYve)"
 __date__            = '2011-January-31'
 __url__             = 'http://postmarkapp.com'
 __copyright__       = "(C) 2009-2010 David Martorana, Wildbit LLC, Python Software Foundation."
-__contributors__    = "Dave Martorana (themartorana), Bill Jones (oraclebill), Richard Cooper (frozenskys), Miguel Araujo (maraujop), Patrick Lauber (digi604), Brian McFadden (brimcfadden)"
+__contributors__    = "Dave Martorana (themartorana), Bill Jones (oraclebill), Richard Cooper (frozenskys), Miguel Araujo (maraujop), Patrick Lauber (digi604), Brian McFadden (brimcfadden), Joel Ryan (joelryan2k), Ben Hodgson (benhodgson), Dmitry Golomidov (deeGraYve)"
 
 __doc__ = '''
 
@@ -14,45 +14,6 @@ __doc__ = '''
     Last Updated: ''' + __date__ + '''
     Contributors: ''' + __contributors__ + '''
 
-    CHANGE LOG:
-        Version 0.2.2
-            - Merged in email mime import fix from brimcfadden
-            
-        Version 0.2.1
-            - Merged in POSTMARK_TEST_MODE Django setting from maraujop
-            
-        Version 0.2.0
-            - Merged with frozenskys/master to bring in PMBounceManager
-            - Support for multiple to/cc (limit: 20 per)
-            - Changed .recipient to .to (legacy support for .recipient left in)
-            - Tag support (.tag) added
-            - Fixed the email endpoint
-            - Fixed a Django backend issue for multiple recipients (max 20)
-    
-    	Version 0.1.6
-    		- Added support for Bounces API
-    		
-        Version 0.1.5
-            - Added ".cc" property for carbon copy recipients. Changed django_backend to 
-              support multiple recipients, and to use "to" rather than "recipients" on the django
-              mail object to prevent accidental leakage of BCC recipients.
-          
-        Version 0.1.4
-            - Added ".reply_to" property.  The "ReplyTo" custom header is unallowed by Postmark 
-              now, and their documentation has been updated to reflect the change.
-              http://developer.postmarkapp.com
-
-        Version 0.1.3
-            - Major fix to the way properties were being used, fixes doc strings in properties
-            - "custom_headers" is now always a dict, even if set to None
-
-        Version 0.1.2
-            - Added 'custom_headers' property (must be a dictionary) to PMMail object
-            - Added optional 'test' argument to send function to print JSON message instead of actually sending it
-            
-        Version 0.1.1:
-            - Initial release
-
     USEAGE:
         Make sure you have a Postmark account.  Visit
         http://postmarkapp.com to sign up for an account.
@@ -61,6 +22,11 @@ __doc__ = '''
         Import postmark.PMMail to use Postmark Sending. 
         Check class documentation on PMMail object for 
         more information.
+
+        Import postmark.PMBatchMail object to send batches of 
+        messages. Either pass a "messages" argument or set 
+        the .messages property of the PMBatchMail object to an
+        array of PMMail objects.
         
         Import postmark.PMBounceManager to use Postmark Bounce API. 
         Check class documentation on PMBounceManager object for 
@@ -72,6 +38,7 @@ __doc__ = '''
         
         POSTMARK_API_KEY = 'your-key'
         POSTMARK_SENDER = '<From Name> from@emailaddress.com'
+        POSTMARK_TEST_MODE = True/False
         
         to your settings.py file, and when you create a new PMMail object,
         it will grab the API key automatically.
